@@ -53,7 +53,7 @@ fn search_paths() -> Vec<PathBuf> {
     }
     match env::var("XDG_DATA_DIRS") {
         Ok(data_dirs) if !data_dirs.is_empty() => {
-            for path in data_dirs.split(":") {
+            for path in data_dirs.split(':') {
                 if !path.is_empty() {
                     paths.push(Path::new(&path).join("icons"));
                 }
@@ -117,6 +117,7 @@ fn find_index(theme_dirs: &[PathBuf]) -> Option<PathBuf> {
 /// *Note*: These are the only image file formats supported by the
 /// Freedesktop standard.
 #[derive(Debug, Eq, PartialEq)]
+#[allow(clippy::upper_case_acronyms)]
 pub enum IconType {
     PNG,
     SVG,
@@ -182,11 +183,11 @@ impl<'a> IconIterState<'a> {
 
         let theme_dirs = find_theme_dirs(&theme_name, &sps, extra_search_paths);
         if theme_dirs.is_empty() {
-            return Err(LiniconError::ThemeNotFound(theme_name.clone()));
+            return Err(LiniconError::ThemeNotFound(theme_name));
         }
 
         let index_file = find_index(&theme_dirs)
-            .ok_or(LiniconError::IndexFileNotFound(theme_name.clone()))?;
+            .ok_or_else(|| LiniconError::IndexFileNotFound(theme_name.clone()))?;
         let file_lock = FileLock::new(&index_file)
             .blocking(true)
             .lock()
@@ -215,7 +216,7 @@ impl<'a> IconIterState<'a> {
         let fallbacks = match &index_header.inherits {
             Some(inherits) => {
                 let mut fallbacks = VecDeque::new();
-                for theme in inherits.split(",") {
+                for theme in inherits.split(',') {
                     if !theme.is_empty() {
                         fallbacks.push_back(theme.to_owned());
                     }
@@ -331,6 +332,7 @@ impl<'a> IconIter<'a> {
     /// be used.
     ///
     /// Will panic if called after calling next.
+    #[allow(clippy::wrong_self_convention)]
     pub fn from_theme(mut self, theme_name: impl AsRef<str>) -> Self {
         if self.state.is_some() {
             panic!("linicon: Cannot change icon iterator settings after iteration has started");
@@ -430,7 +432,7 @@ impl<'a> Iterator for IconIter<'a> {
                 };
             }
             match self.lookup_icon() {
-                Ok(icon_path) => icon_path.map(|p| Ok(p)),
+                Ok(icon_path) => icon_path.map(Ok),
                 Err(e) => Some(Err(e)),
             }
         }
@@ -589,7 +591,7 @@ fn _themes(extra_search_paths: Option<&Vec<PathBuf>>) -> Vec<Theme> {
                         themes
                             .entry(s)
                             .and_modify(|e| e.push(entry.path()))
-                            .or_insert(vec![entry.path()]);
+                            .or_insert_with(|| vec![entry.path()]);
                     }
                     Err(_) => continue,
                 },
@@ -624,11 +626,11 @@ fn _themes(extra_search_paths: Option<&Vec<PathBuf>>) -> Vec<Theme> {
                         Err(_) => return None,
                     };
                     Some(Theme {
-                        name: name.to_owned(),
+                        name,
                         paths,
                         display_name: index_header.name,
                         inherits: index_header.inherits.map(|s| {
-                            s.split(",").map(|s| s.to_owned()).collect()
+                            s.split(',').map(|s| s.to_owned()).collect()
                         }),
                         comment: index_header.comment,
                     })
